flutterflow_pulse library

Classes

ClientProvider
A singleton class for managing NATS client connections.
ContextProvider
A singleton to manage and provide access to the BuildContext across the app
MessageHandler
MessageHandler is responsible for processing incoming messages and delegating to the appropriate specialized handlers.
MessageHandlerInterface
Interface for message handlers
SubscriptionService
SubscriptionService handles subscribing to channels and delegates message processing.

Properties

contextProvider ContextProvider
final

Functions

getCurrentContext() BuildContext?
initializeContextProvider() Future<void>
setCurrentContext(BuildContext context, {String? pageName}) → void
subscribeChannel(String channel) Future
The public function that FlutterFlow will call